@@ -6,7 +6,7 @@
 # For more information about the API and the return values,
 # visit the official documentation at http://developers.face.com/docs/api/.
 #
-# Author: Tomaž Muraus (http://www.tomaz-muraus.info)
+# Author: Tomaž Muraus (http://www.tomaz.me)
 # License: BSD
 
 from __future__ import with_statement
@@ -14,6 +14,7 @@ from __future__ import with_statement
 import urllib
 import urllib2
 import os.path
+import warnings
 
 try:
     import json
@@ -35,12 +36,10 @@ class FaceClient(object):
         self.twitter_credentials = None
         self.facebook_credentials = None
 
-    def set_twitter_user_credentials(self, user=None, password=None):
-        if not user or not password:
-            raise AttributeError('Missing Twitter username or password')
-
-        self.twitter_credentials = {'twitter_user': user,
-                                    'twitter_password': password}
+    def set_twitter_user_credentials(self, *args, **kwargs):
+        warnings.warn(('Twitter username & password auth has been ' +
+                      'deprecated. Please use oauth based auth - ' +
+                      'set_twitter_oauth_credentials()'))
 
     def set_twitter_oauth_credentials(self, user=None, secret=None,
                                       token=None):
@@ -51,12 +50,22 @@ class FaceClient(object):
                                     'twitter_oauth_secret': secret,
                                     'twitter_oauth_token': token}
 
-    def set_facebook_credentials(self, user=None, session=None):
-        if not user or not session:
-            raise AttributeError('Missing Facebook user or session argument')
+    def set_facebook_access_token(self, *args, **kwargs):
+        warnings.warn(('Method has been renamed to ' +
+                       ' set_facebook_oauth_credentials(). Support for' +
+                      'username & password based auth has also been dropped.' +
+                      'Now only oAuth2 token based auth is supported'))
 
-        self.facebook_credentials = {'fb_user': user,
-                                    'fb_session': session}
+    def set_facebook_oauth_credentials(self, user_id=None, session_id=None,
+                                       oauth_token=None):
+        for (key, value) in [('user_id', user_id), ('session_id', session_id),
+                             ('oauth_token', oauth_token)]:
+            if not value:
+                raise AttributeError('Missing required argument: %s' % (key))
+
+        self.facebook_credentials = {'fb_user_id': user_id,
+                                     'fb_session_id': session_id,
+                                     'fb_oauth_token': oauth_token}
 
     ### Recognition engine methods ###
     def faces_detect(self, urls=None, file=None, aggressive=False):
@@ -82,6 +91,8 @@ class FaceClient(object):
         if aggressive:
             data['detector'] = 'Aggressive'
 
+        data['attributes'] = 'all'
+
         response = self.send_request('faces/detect', data)
         return response
 
@@ -122,7 +133,7 @@ class FaceClient(object):
         (facebook_uids, twitter_uids) = \
                 self.__check_user_auth_credentials(uids)
 
-        data = {'uids': uids}
+        data = {'uids': uids, 'attributes': 'all'}
 
         if file:
             # Check if the file exists
@@ -293,26 +304,19 @@ class FaceClient(object):
 
     def __append_user_auth_data(self, data, facebook_uids, twitter_uids):
         if facebook_uids:
-            data.update({'user_auth': 'fb_user:%s,fb_session:%s' %
-                         (self.facebook_credentials['fb_user'],
-                         self.facebook_credentials['fb_session'])})
+            data.update({'user_auth': 'fb_user:%s,fb_session:%s,' +
+                                      'fb_oauth_token:%s' %
+                         (self.facebook_credentials['fb_user_id'],
+                          self.facebook_credentials['fb_session_id'],
+                          self.facebook_credentials['fb_oauth_token'])})
 
         if twitter_uids:
-            # If both user/password and OAuth credentials are provided, use
-            # OAuth as default
-            if self.twitter_credentials.get('twitter_oauth_user', None):
-                data.update({'user_auth':
-                             ('twitter_oauth_user:%s,twitter_oauth_secret:%s,'
-                              'twitter_oauth_token:%s' %
-                            (self.twitter_credentials['twitter_oauth_user'],
-                             self.twitter_credentials['twitter_oauth_secret'],
-                             self.twitter_credentials['twitter_oauth_token']))}
-                            )
-            else:
-                data.update({'user_auth':
-                             'twitter_user:%s,twitter_password:%s' %
-                             (self.twitter_credentials['twitter_user'],
-                             self.twitter_credentials['twitter_password'])})
+            data.update({'user_auth':
+                         ('twitter_oauth_user:%s,twitter_oauth_secret:%s,'
+                          'twitter_oauth_token:%s' %
+                        (self.twitter_credentials['twitter_oauth_user'],
+                         self.twitter_credentials['twitter_oauth_secret'],
+                         self.twitter_credentials['twitter_oauth_token']))})
 
     def __append_optional_arguments(self, data, **kwargs):
         for key, value in kwargs.iteritems():
